@@ -217,14 +217,27 @@ impl<'a> Interface<'a> {
         let result_top_index = self.result_top_index();
         queue!(screen, cursor::Hide, cursor::MoveTo(1, result_top_index)).unwrap();
 
-        let (width, _height): (u16, u16) = terminal::size().unwrap();
+        let (width, height): (u16, u16) = terminal::size().unwrap();
+        let result_height = (height - RESULTS_TOP_INDEX) as usize
+            + if self.is_screen_view_bottom() { 1 } else { 0 };
 
         if !self.matches.is_empty() && self.selection > self.matches.len() - 1 {
             self.selection = self.matches.len() - 1;
         }
 
-        let mut index: usize = 0;
-        for command in &self.matches {
+        let mut index = 0;
+        let in_page = self.selection < result_height;
+
+        let view_range = if in_page {
+            let len = result_height.min(self.matches.len());
+            &self.matches[..len]
+        } else {
+            let offset = self.selection - result_height + 1;
+            let len = (offset + result_height).min(self.matches.len());
+            &self.matches[offset..len]
+        };
+
+        for command in view_range {
             let mut fg = if self.settings.lightmode {
                 self.settings.colors.lightmode_colors.results_fg
             } else {
@@ -239,7 +252,7 @@ impl<'a> Interface<'a> {
 
             let mut bg = Color::Reset;
 
-            if index == self.selection {
+            if index == self.selection.min(result_height - 1) {
                 if self.settings.lightmode {
                     fg = self.settings.colors.lightmode_colors.results_selection_fg;
                     bg = self.settings.colors.lightmode_colors.results_selection_bg;
@@ -329,9 +342,10 @@ impl<'a> Interface<'a> {
             }
             index += 1;
         }
+
         // Since we only clear by line instead of clearing the screen each update,
         //  we need to clear all the lines that may have previously had a command
-        for i in index..(self.settings.results as usize) {
+        for i in index..result_height {
             let command_line_index = self.command_line_index(i as i16);
             queue!(
                 screen,
@@ -712,6 +726,9 @@ impl<'a> Interface<'a> {
     }
 
     fn select_with_vim_key_scheme(&mut self, event: KeyEvent) -> bool {
+        if event.kind != KeyEventKind::Press {
+            return false;
+        }
         if self.in_vim_insert_mode {
             match event {
                 KeyEvent {
